@@ -151,7 +151,7 @@
 #' @return The function does not return anything. Its side effect (the production
 #' of a data report) is the reason for running the function.
 #'
-#' @references Petersen AH, Ekstrøm CT (2019). “dataMaid: Your Assistant for Documenting Supervised Data Quality Screening in R.” _Journal of Statistical Software_, *90*(6), 1-38. doi: 10.18637/jss.v090.i06 ( \url{https://doi.org/10.18637/jss.v090.i06}).
+#' @references Petersen AH, Ekstrøm CT (2019). “dataMaid: Your Assistant for Documenting Supervised Data Quality Screening in R.” _Journal of Statistical Software_, *90*(6), 1-38. doi: 10.18637/jss.v090.i06 ( \doi{10.18637/jss.v090.i06}).
 #'
 #' @examples
 #' data(testData)
@@ -762,6 +762,7 @@ makeDataReport <- function(data, output=NULL, render=TRUE,
       ## List of variables
       writer("# Variable list", outfile = vListConn)
       
+    #  browser()
 
       ## Run through each of the variables in the data frame
       for (idx in index) {
@@ -818,8 +819,10 @@ makeDataReport <- function(data, output=NULL, render=TRUE,
         }
         
         ## use smartNum
+        ## Note: no smartNum on haven_labelled - they inherit from integer/numeric
         if (smartNum & !("fakeLabelled" %in% class(v)) & !userSuppVar & 
-            any(class(v) %in% c("numeric", "integer"))) {
+            any(class(v) %in% c("numeric", "integer")) &
+            !("haven_labelled" %in% class(v))) {
           v <- doSmartNum(v, ...)
           if ("smartNum" %in% class(v)) {
             extraMessages$do <- TRUE
